<?php

namespace Drupal\elementpay\Events;

/** Class for processing 'Pay' requests from EPS Callback API */
class EventPay extends BaseEvent {
  public function handle($event) {
    if (!$this->isHashValid($event)) {
      return $this->sendResponse(401, 'Invalid hash');
    }

    if (!$this->isOrderValid($event) || !$this->amountMatching($event) || $this->isOrderCanceled()) {
      return $this->sendResponse(475, 'Payment with the specified parameters can not be processed');
    }

    if ($this->isOrderPaid()) {
      return $this->sendResponse(205, 'Payment success');
    }

    if (!$this->isPaymentStatusSuccess($event)) {
      \Drupal::logger('EPS Webhooks')->info('status of order#' . $event['order'] . ' change to "Canceled"');

      $order = $this->payment->getOrder();
      $order->set('state', 'canceled')->save();

      return $this->sendResponse(475, 'Payment with the specified parameters can not be processed');
    }

    $order = $this->payment->getOrder();
    $order->set('state', 'completed')->save();

    \Drupal::logger('EPS Webhooks')->info('status of order#' . $event['order'] . ' change to "Payment accepted"');
    return $this->sendResponse(205, 'Payment success');
  }

  private function isPaymentStatusSuccess($event) : bool {
    $status = $this->provider->getPaymentStatus($event['id']);
    if ($status != 203 && $status != 205) {
      \Drupal::logger('EPS Webhooks')->info('The status of order #' . $event['order'] . ' in EPS API is not success.');
      return false;
    }
    return true;
  }
}
